@@ -11,12 +11,17 @@ import httpx
 from botoy import macro
 from botoy.config import Config
 from botoy.log import logger
+from botoy.model import EventMsg, FriendMsg, GroupMsg
 
 
 class Action:
-    def __init__(self, qq: int, port: int = None, host: str = None, timeout=20):
-        self.qq = qq
+    def __init__(
+        self, qq: int = None, port: int = None, host: str = None, timeout: int = 20
+    ):
         self.config = Config(host=host, port=port)
+
+        self.qq = int(qq or self.config.qq)
+
         self.c = httpx.Client(
             headers={"Content-Type": "application/json"},
             timeout=timeout + 5,
@@ -25,6 +30,17 @@ class Action:
         )
         self.lock = threading.Lock()
 
+    @classmethod
+    def from_ctx(
+        cls, ctx: Union[EventMsg, FriendMsg, GroupMsg], timeout: int = 20
+    ) -> "Action":
+        return cls(
+            ctx.CurrentQQ,
+            host=getattr(ctx, "_host", None),
+            port=getattr(ctx, "_port", None),
+            timeout=timeout,
+        )
+
     ############发送相关############
     def sendFriendText(self, user: int, content: str) -> dict:
         """发送好友文本消息"""
