@@ -1,6 +1,6 @@
 import threading
 import time
-from typing import Any, Callable, Dict, List, Optional, TypeVar, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union
 from uuid import uuid4
 
 from ..action import Action
@@ -257,8 +257,10 @@ class Session(SessionBase):
         retry_times: int = 1,
         always_prompt: bool = True,
         timeout: int = 30,
-    ) -> Optional[T]:
-        """提示用户发送序号选择列表中的一项
+    ) -> Optional[Tuple[T, int]]:
+        """提示用户发送序号选择列表中的一项,
+        返回值是一个元组，第一项为选择项，第二项为选择项的索引. 超过重试次数，返回None
+
         :param candidates: 选项列表
         :param retry_times: 获取重试次数
         :param always_prompt: 重试时是否再次发送提示
@@ -278,7 +280,8 @@ class Session(SessionBase):
                 prompt = msg if always_prompt else None
             what: str = self.want(str(uuid4()), prompt, pop=True, timeout=timeout)
             try:
-                return candidates[int(what) - 1]
+                idx = int(what) - 1
+                return candidates[idx], idx
             except Exception:
                 self.send_text("序号错误")
 
