@@ -11,7 +11,6 @@ from . import macro
 from .action import Action
 from .async_action import AsyncAction
 from .collection import MsgTypes
-from .log import logger
 from .model import FriendMsg, GroupMsg
 from .utils import file_to_base64
 
@@ -43,11 +42,7 @@ def Text(text: str, at=False):
     text = str(text)
 
     ctx = find_ctx()
-    action = Action(
-        ctx.CurrentQQ,
-        host=getattr(ctx, "_host", None),
-        port=getattr(ctx, "_port", None),
-    )
+    action = Action.from_ctx(ctx)
 
     if isinstance(ctx, GroupMsg):
         return action.sendGroupText(
@@ -76,11 +71,7 @@ def Picture(pic_url="", pic_base64="", pic_path="", pic_md5="", text=""):
     assert any([pic_url, pic_base64, pic_path, pic_md5]), "必须给定一项"
 
     ctx = find_ctx()
-    action = Action(
-        ctx.CurrentQQ,
-        host=getattr(ctx, "_host", None),
-        port=getattr(ctx, "_port", None),
-    )
+    action = Action.from_ctx(ctx)
 
     if isinstance(ctx, GroupMsg):
         if pic_url:
@@ -153,11 +144,7 @@ def Voice(voice_url="", voice_base64="", voice_path=""):
     assert any([voice_url, voice_base64, voice_path]), "必须给定一项"
 
     ctx = find_ctx()
-    action = Action(
-        ctx.CurrentQQ,
-        host=getattr(ctx, "_host", None),
-        port=getattr(ctx, "_port", None),
-    )
+    action = Action.from_ctx(ctx)
 
     if isinstance(ctx, GroupMsg):
         if voice_url:
@@ -303,26 +290,18 @@ class _S:
         :param at: 是否要艾特该用户
         """
         ctx = self.ctx
-        action = Action(
-            ctx.CurrentQQ,
-            host=getattr(ctx, "_host", None),
-            port=getattr(ctx, "_port", None),
-        )
+        action = Action.from_ctx(ctx)
 
         if isinstance(ctx, GroupMsg):
-            logger.debug("发送群聊文字")
             return action.sendGroupText(
                 ctx.FromGroupId, text, atUser=ctx.FromUserId if at else 0
             )
         elif isinstance(ctx, FriendMsg):
             if ctx.TempUin:
-                logger.debug("发送私聊文字")
                 return action.sendPrivateText(ctx.FromUin, ctx.TempUin, text)
             elif ctx.MsgType == MsgTypes.PhoneMsg:
-                logger.debug("发送手机文字")
                 return action.sendPhoneText(text)
             else:
-                logger.debug("发送好友文字")
                 return action.sendFriendText(ctx.FromUin, text)
         return None
 
@@ -336,11 +315,7 @@ class _S:
         :param type: 发送内容的类型, 默认自动判断，可选值为 S.TYPE_?
         """
         ctx = self.ctx
-        action = Action(
-            ctx.CurrentQQ,
-            host=getattr(ctx, "_host", None),
-            port=getattr(ctx, "_port", None),
-        )
+        action = Action.from_ctx(ctx)
 
         if type not in (
             TYPE_URL,
@@ -355,35 +330,28 @@ class _S:
                 text = macro.atUser(ctx.FromUserId) + text
 
             if type == TYPE_URL:
-                logger.debug("发送群聊网络图片")
                 return action.sendGroupPic(ctx.FromGroupId, content=text, picUrl=data)  # type: ignore
             elif type == TYPE_BASE64:
-                logger.debug("发送群聊base64图片")
                 return action.sendGroupPic(ctx.FromGroupId, content=text, picBase64Buf=data)  # type: ignore
             elif type == TYPE_MD5:
-                logger.debug("发送群聊md5图片")
                 return action.sendGroupPic(
                     ctx.FromGroupId, content=text, picMd5s=data  # type:ignore
                 )
             elif type == TYPE_PATH:
-                logger.debug("发送群聊本地图片")
                 return action.sendGroupPic(
                     ctx.FromGroupId, content=text, picBase64Buf=file_to_base64(data)
                 )
         elif isinstance(ctx, FriendMsg):
             if ctx.TempUin:
                 if type == TYPE_URL:
-                    logger.debug("发送私聊网络图片")
                     return action.sendPrivatePic(
                         ctx.FromUin, ctx.TempUin, content=text, picUrl=data  # type: ignore
                     )
                 elif type == TYPE_BASE64:
-                    logger.debug("发送私聊base64图片")
                     return action.sendPrivatePic(
                         ctx.FromUin, ctx.TempUin, content=text, picBase64Buf=data  # type: ignore
                     )
                 elif type == TYPE_MD5:
-                    logger.debug("发送私聊md5图片")
                     return action.sendPrivatePic(
                         ctx.FromUin,
                         ctx.TempUin,
@@ -391,22 +359,17 @@ class _S:
                         fileMd5=data,  # type:ignore
                     )
                 elif type == TYPE_PATH:
-                    logger.debug("发送私聊本地图片")
                     return action.sendPrivatePic(
                         ctx.FromUin, ctx.TempUin, content=text, picBase64Buf=file_to_base64(data)  # type: ignore
                     )
             else:
                 if type == TYPE_URL:
-                    logger.debug("发送好友链接图片")
                     return action.sendFriendPic(ctx.FromUin, content=text, picUrl=data)  # type: ignore
                 elif type == TYPE_BASE64:
-                    logger.debug("发送好友base64图片")
                     return action.sendFriendPic(ctx.FromUin, content=text, picBase64Buf=data)  # type: ignore
                 elif type == TYPE_MD5:
-                    logger.debug("发送好友md5图片")
                     return action.sendFriendPic(ctx.FromUin, content=text, fileMd5=data)  # type: ignore
                 elif type == TYPE_PATH:
-                    logger.debug("发送好友本地图片")
                     return action.sendFriendPic(ctx.FromUin, content=text, picBase64Buf=file_to_base64(data))  # type: ignore
 
         return None
@@ -419,11 +382,7 @@ class _S:
         :param type: 发送内容的类型, 默认自动判断，可选值为 S.TYPE_?
         """
         ctx = self.ctx
-        action = Action(
-            ctx.CurrentQQ,
-            host=getattr(ctx, "_host", None),
-            port=getattr(ctx, "_port", None),
-        )
+        action = Action.from_ctx(ctx)
 
         if type not in (
             TYPE_URL,
@@ -437,41 +396,32 @@ class _S:
 
         if isinstance(ctx, GroupMsg):
             if type == TYPE_URL:
-                logger.debug("发送群聊网络语音")
                 return action.sendGroupVoice(ctx.FromGroupId, voiceUrl=data)  # type: ignore
             elif type == TYPE_BASE64:
-                logger.debug("发送群聊base64语音")
                 return action.sendGroupVoice(ctx.FromGroupId, voiceBase64Buf=data)  # type: ignore
             elif type == TYPE_PATH:
-                logger.debug("发送群聊本地语音")
                 return action.sendGroupVoice(ctx.FromGroupId, voiceBase64Buf=file_to_base64(data))  # type: ignore
 
         elif isinstance(ctx, FriendMsg):
             if ctx.TempUin:
                 if type == TYPE_URL:
-                    logger.debug("发送私聊网络语音")
                     return action.sendPrivateVoice(
                         ctx.FromUin, ctx.TempUin, voiceUrl=data  # type: ignore
                     )
                 elif type == TYPE_BASE64:
-                    logger.debug("发送私聊base64语音")
                     return action.sendPrivateVoice(
                         ctx.FromUin, ctx.TempUin, voiceBase64Buf=data  # type: ignore
                     )
                 elif type == TYPE_PATH:
-                    logger.debug("发送私聊本地语音")
                     return action.sendPrivateVoice(
                         ctx.FromUin, ctx.TempUin, voiceBase64Buf=file_to_base64(data)  # type: ignore
                     )
             else:
                 if type == TYPE_URL:
-                    logger.debug("发送好友网络语音")
                     return action.sendFriendVoice(ctx.FromUin, voiceUrl=data)  # type: ignore
                 elif type == TYPE_BASE64:
-                    logger.debug("发送好友base64语音")
                     return action.sendFriendVoice(ctx.FromUin, voiceBase64Buf=data)  # type: ignore
                 elif type == TYPE_PATH:
-                    logger.debug("发送好友本地语音")
                     return action.sendFriendVoice(ctx.FromUin, voiceBase64Buf=file_to_base64(data))  # type: ignore
 
         return None
@@ -482,25 +432,17 @@ class _S:
         :param at: 是否要艾特该用户
         """
         ctx = self.ctx
-        async with AsyncAction(
-            ctx.CurrentQQ,
-            host=getattr(ctx, "_host", None),
-            port=getattr(ctx, "_port", None),
-        ) as action:
+        async with AsyncAction.from_ctx(ctx) as action:
             if isinstance(ctx, GroupMsg):
-                logger.debug("发送群聊文字")
                 return await action.sendGroupText(
                     ctx.FromGroupId, text, atUser=ctx.FromUserId if at else 0
                 )
             elif isinstance(ctx, FriendMsg):
                 if ctx.TempUin:
-                    logger.debug("发送私聊文字")
                     return await action.sendPrivateText(ctx.FromUin, ctx.TempUin, text)
                 elif ctx.MsgType == MsgTypes.PhoneMsg:
-                    logger.debug("发送手机文字")
                     return await action.sendPhoneText(text)
                 else:
-                    logger.debug("发送好友文字")
                     return await action.sendFriendText(ctx.FromUin, text)
 
     async def aimage(
@@ -524,46 +466,35 @@ class _S:
             type, data = _resolve_data_type(data)
 
         ctx = self.ctx
-        async with AsyncAction(
-            ctx.CurrentQQ,
-            host=getattr(ctx, "_host", None),
-            port=getattr(ctx, "_port", None),
-        ) as action:
+        async with AsyncAction.from_ctx(ctx) as action:
 
             if isinstance(ctx, GroupMsg):
                 if at:
                     text = macro.atUser(ctx.FromUserId) + text
 
                 if type == TYPE_URL:
-                    logger.debug("发送群聊网络图片")
                     return await action.sendGroupPic(ctx.FromGroupId, content=text, picUrl=data)  # type: ignore
                 elif type == TYPE_BASE64:
-                    logger.debug("发送群聊base64图片")
                     return await action.sendGroupPic(ctx.FromGroupId, content=text, picBase64Buf=data)  # type: ignore
                 elif type == TYPE_MD5:
-                    logger.debug("发送群聊md5图片")
                     return await action.sendGroupPic(
                         ctx.FromGroupId, content=text, picMd5s=data  # type:ignore
                     )
                 elif type == TYPE_PATH:
-                    logger.debug("发送群聊本地图片")
                     return await action.sendGroupPic(
                         ctx.FromGroupId, content=text, picBase64Buf=file_to_base64(data)
                     )
             elif isinstance(ctx, FriendMsg):
                 if ctx.TempUin:
                     if type == TYPE_URL:
-                        logger.debug("发送私聊网络图片")
                         return await action.sendPrivatePic(
                             ctx.FromUin, ctx.TempUin, content=text, picUrl=data  # type: ignore
                         )
                     elif type == TYPE_BASE64:
-                        logger.debug("发送私聊base64图片")
                         return await action.sendPrivatePic(
                             ctx.FromUin, ctx.TempUin, content=text, picBase64Buf=data  # type: ignore
                         )
                     elif type == TYPE_MD5:
-                        logger.debug("发送私聊md5图片")
                         return await action.sendPrivatePic(
                             ctx.FromUin,
                             ctx.TempUin,
@@ -571,22 +502,17 @@ class _S:
                             fileMd5=data,  # type:ignore
                         )
                     elif type == TYPE_PATH:
-                        logger.debug("发送私聊本地图片")
                         return await action.sendPrivatePic(
                             ctx.FromUin, ctx.TempUin, content=text, picBase64Buf=file_to_base64(data)  # type: ignore
                         )
                 else:
                     if type == TYPE_URL:
-                        logger.debug("发送好友链接图片")
                         return await action.sendFriendPic(ctx.FromUin, content=text, picUrl=data)  # type: ignore
                     elif type == TYPE_BASE64:
-                        logger.debug("发送好友base64图片")
                         return await action.sendFriendPic(ctx.FromUin, content=text, picBase64Buf=data)  # type: ignore
                     elif type == TYPE_MD5:
-                        logger.debug("发送好友md5图片")
                         return await action.sendFriendPic(ctx.FromUin, content=text, fileMd5=data)  # type: ignore
                     elif type == TYPE_PATH:
-                        logger.debug("发送好友本地图片")
                         return await action.sendFriendPic(ctx.FromUin, content=text, picBase64Buf=file_to_base64(data))  # type: ignore
 
     async def avoice(self, data: _T_Data, type: int = 0):
@@ -608,49 +534,36 @@ class _S:
         assert type != TYPE_MD5, "语音不支持MD5发送"
 
         ctx = self.ctx
-        async with AsyncAction(
-            ctx.CurrentQQ,
-            host=getattr(ctx, "_host", None),
-            port=getattr(ctx, "_port", None),
-        ) as action:
+        async with AsyncAction.from_ctx(ctx) as action:
 
             if isinstance(ctx, GroupMsg):
                 if type == TYPE_URL:
-                    logger.debug("发送群聊网络语音")
                     return await action.sendGroupVoice(ctx.FromGroupId, voiceUrl=data)  # type: ignore
                 elif type == TYPE_BASE64:
-                    logger.debug("发送群聊base64语音")
                     return await action.sendGroupVoice(ctx.FromGroupId, voiceBase64Buf=data)  # type: ignore
                 elif type == TYPE_PATH:
-                    logger.debug("发送群聊本地语音")
                     return await action.sendGroupVoice(ctx.FromGroupId, voiceBase64Buf=file_to_base64(data))  # type: ignore
 
             elif isinstance(ctx, FriendMsg):
                 if ctx.TempUin:
                     if type == TYPE_URL:
-                        logger.debug("发送私聊网络语音")
                         return await action.sendPrivateVoice(
                             ctx.FromUin, ctx.TempUin, voiceUrl=data  # type: ignore
                         )
                     elif type == TYPE_BASE64:
-                        logger.debug("发送私聊base64语音")
                         return await action.sendPrivateVoice(
                             ctx.FromUin, ctx.TempUin, voiceBase64Buf=data  # type: ignore
                         )
                     elif type == TYPE_PATH:
-                        logger.debug("发送私聊本地语音")
                         return await action.sendPrivateVoice(
                             ctx.FromUin, ctx.TempUin, voiceBase64Buf=file_to_base64(data)  # type: ignore
                         )
                 else:
                     if type == TYPE_URL:
-                        logger.debug("发送好友网络语音")
                         return await action.sendFriendVoice(ctx.FromUin, voiceUrl=data)  # type: ignore
                     elif type == TYPE_BASE64:
-                        logger.debug("发送好友base64语音")
                         return await action.sendFriendVoice(ctx.FromUin, voiceBase64Buf=data)  # type: ignore
                     elif type == TYPE_PATH:
-                        logger.debug("发送好友本地语音")
                         return await action.sendFriendVoice(ctx.FromUin, voiceBase64Buf=file_to_base64(data))  # type: ignore
 
 
